==> ejc-jlincome-api-3.0.0-20241011.080417-302-sources.jar: com/ejianc/business/jlincome/income/vo/ProjectBoardTwoVO.java <==
package com.ejianc.business.jlincome.income.vo;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目看板2
 * 
 * @author generator
 * 
 */
public class ProjectBoardTwoVO extends BaseVO {
    private static final long serialVersionUID = 1L;


    private String name; //项目名称
    private String projectStatus;
    private Integer warnNum = 0; //现阶段预警数
    private String productType;
    private String productTypeName;
    private Long projectTypeId;
    private String projectTypeName;
    private Long projectDepartmentId;
    private String projectDepartmentName;
    private String projectDepartmentCode;

    private BigDecimal contractTaxMny = BigDecimal.ZERO; //合同金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date firstOrderDate; //转单日期
    private String productOutState = "未发货"; // 发货记录
    private String wbsState = "是"; // 是否做wbs
    private BigDecimal sumInvoiceTaxMny = BigDecimal.ZERO; //开票金额
    private BigDecimal sumReceiveTaxMny = BigDecimal.ZERO; //回款金额
    private BigDecimal sumSettleTaxMny = BigDecimal.ZERO; //对甲结算金额

    private List<JSONObject> contractList = new ArrayList<>(); // 合同登记明细
    private List<JSONObject> salesList = new ArrayList<>(); // 销售订单明细
    private List<JSONObject> productOutVOList = new ArrayList<>(); // 发货明细
    private List<JSONObject> invoiceDetailList = new ArrayList<>(); // 开票明细
    private List<JSONObject> receiveDetailList = new ArrayList<>(); // 收款明细
    private List<JSONObject> settleList = new ArrayList<>(); // 结算明细

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }

    public Integer getWarnNum() {
        return warnNum;
    }

    public void setWarnNum(Integer warnNum) {
        this.warnNum = warnNum;
    }

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }

    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getProjectDepartmentName() {
        return projectDepartmentName;
    }

    public void setProjectDepartmentName(String projectDepartmentName) {
        this.projectDepartmentName = projectDepartmentName;
    }

    public String getProjectDepartmentCode() {
        return projectDepartmentCode;
    }

    public void setProjectDepartmentCode(String projectDepartmentCode) {
        this.projectDepartmentCode = projectDepartmentCode;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public Date getFirstOrderDate() {
        return firstOrderDate;
    }

    public void setFirstOrderDate(Date firstOrderDate) {
        this.firstOrderDate = firstOrderDate;
    }

    public String getProductOutState() {
        return productOutState;
    }

    public void setProductOutState(String productOutState) {
        this.productOutState = productOutState;
    }

    public String getWbsState() {
        return wbsState;
    }

    public void setWbsState(String wbsState) {
        this.wbsState = wbsState;
    }

    public BigDecimal getSumInvoiceTaxMny() {
        return sumInvoiceTaxMny;
    }

    public void setSumInvoiceTaxMny(BigDecimal sumInvoiceTaxMny) {
        this.sumInvoiceTaxMny = sumInvoiceTaxMny;
    }

    public BigDecimal getSumReceiveTaxMny() {
        return sumReceiveTaxMny;
    }

    public void setSumReceiveTaxMny(BigDecimal sumReceiveTaxMny) {
        this.sumReceiveTaxMny = sumReceiveTaxMny;
    }

    public BigDecimal getSumSettleTaxMny() {
        return sumSettleTaxMny;
    }

    public void setSumSettleTaxMny(BigDecimal sumSettleTaxMny) {
        this.sumSettleTaxMny = sumSettleTaxMny;
    }

    public List<JSONObject> getSalesList() {
        return salesList;
    }

    public void setSalesList(List<JSONObject> salesList) {
        this.salesList = salesList;
    }

    public List<JSONObject> getProductOutVOList() {
        return productOutVOList;
    }

    public void setProductOutVOList(List<JSONObject> productOutVOList) {
        this.productOutVOList = productOutVOList;
    }

    public List<JSONObject> getInvoiceDetailList() {
        return invoiceDetailList;
    }

    public void setInvoiceDetailList(List<JSONObject> invoiceDetailList) {
        this.invoiceDetailList = invoiceDetailList;
    }

    public List<JSONObject> getReceiveDetailList() {
        return receiveDetailList;
    }

    public void setReceiveDetailList(List<JSONObject> receiveDetailList) {
        this.receiveDetailList = receiveDetailList;
    }

    public List<JSONObject> getSettleList() {
        return settleList;
    }

    public void setSettleList(List<JSONObject> settleList) {
        this.settleList = settleList;
    }

    public List<JSONObject> getContractList() {
        return contractList;
    }

    public void setContractList(List<JSONObject> contractList) {
        this.contractList = contractList;
    }
}

==> ejc-jlincome-api-3.0.0-20241105.091410-320-sources.jar: com/ejianc/business/jlincome/income/vo/ProjectBoardTwoVO.java <==
package com.ejianc.business.jlincome.income.vo;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 项目看板2
 * 
 * @author generator
 * 
 */
public class ProjectBoardTwoVO extends BaseVO {
    private static final long serialVersionUID = 1L;


    private String name; //项目名称
    private String projectStatus;
    private Integer warnNum = 0; //现阶段预警数
    private String productType;
    private String productTypeName;
    private Long projectTypeId;
    private String projectTypeName;
    private Long projectDepartmentId;
    private String projectDepartmentName;
    private String projectDepartmentCode;

    private BigDecimal contractTaxMny = BigDecimal.ZERO; //合同金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date firstOrderDate; //转单日期
    private String productOutState = "未发货"; // 发货记录
    private String wbsState = "是"; // 是否做wbs
    private BigDecimal sumInvoiceTaxMny = BigDecimal.ZERO; //开票金额
    private BigDecimal sumReceiveTaxMny = BigDecimal.ZERO; //回款金额
    private BigDecimal sumSettleTaxMny = BigDecimal.ZERO; //对甲结算金额
    private List<Integer> projectStatusList; // 项目阶段集合

    private List<JSONObject> contractList = new ArrayList<>(); // 合同登记明细
    private List<JSONObject> salesList = new ArrayList<>(); // 销售订单明细
    private List<JSONObject> productOutVOList = new ArrayList<>(); // 发货明细
    private List<JSONObject> invoiceDetailList = new ArrayList<>(); // 开票明细
    private List<JSONObject> receiveDetailList = new ArrayList<>(); // 收款明细
    private List<JSONObject> settleList = new ArrayList<>(); // 结算明细

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(String projectStatus) {
        this.projectStatus = projectStatus;
    }

    public Integer getWarnNum() {
        return warnNum;
    }

    public void setWarnNum(Integer warnNum) {
        this.warnNum = warnNum;
    }

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getProductTypeName() {
        return productTypeName;
    }

    public void setProductTypeName(String productTypeName) {
        this.productTypeName = productTypeName;
    }

    public Long getProjectTypeId() {
        return projectTypeId;
    }

    public void setProjectTypeId(Long projectTypeId) {
        this.projectTypeId = projectTypeId;
    }

    public String getProjectTypeName() {
        return projectTypeName;
    }

    public void setProjectTypeName(String projectTypeName) {
        this.projectTypeName = projectTypeName;
    }

    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getProjectDepartmentName() {
        return projectDepartmentName;
    }

    public void setProjectDepartmentName(String projectDepartmentName) {
        this.projectDepartmentName = projectDepartmentName;
    }

    public String getProjectDepartmentCode() {
        return projectDepartmentCode;
    }

    public void setProjectDepartmentCode(String projectDepartmentCode) {
        this.projectDepartmentCode = projectDepartmentCode;
    }

    public BigDecimal getContractTaxMny() {
        return contractTaxMny;
    }

    public void setContractTaxMny(BigDecimal contractTaxMny) {
        this.contractTaxMny = contractTaxMny;
    }

    public Date getFirstOrderDate() {
        return firstOrderDate;
    }

    public void setFirstOrderDate(Date firstOrderDate) {
        this.firstOrderDate = firstOrderDate;
    }

    public String getProductOutState() {
        return productOutState;
    }

    public void setProductOutState(String productOutState) {
        this.productOutState = productOutState;
    }

    public String getWbsState() {
        return wbsState;
    }

    public void setWbsState(String wbsState) {
        this.wbsState = wbsState;
    }

    public BigDecimal getSumInvoiceTaxMny() {
        return sumInvoiceTaxMny;
    }

    public void setSumInvoiceTaxMny(BigDecimal sumInvoiceTaxMny) {
        this.sumInvoiceTaxMny = sumInvoiceTaxMny;
    }

    public BigDecimal getSumReceiveTaxMny() {
        return sumReceiveTaxMny;
    }

    public void setSumReceiveTaxMny(BigDecimal sumReceiveTaxMny) {
        this.sumReceiveTaxMny = sumReceiveTaxMny;
    }

    public BigDecimal getSumSettleTaxMny() {
        return sumSettleTaxMny;
    }

    public void setSumSettleTaxMny(BigDecimal sumSettleTaxMny) {
        this.sumSettleTaxMny = sumSettleTaxMny;
    }

    public List<JSONObject> getSalesList() {
        return salesList;
    }

    public void setSalesList(List<JSONObject> salesList) {
        this.salesList = salesList;
    }

    public List<JSONObject> getProductOutVOList() {
        return productOutVOList;
    }

    public void setProductOutVOList(List<JSONObject> productOutVOList) {
        this.productOutVOList = productOutVOList;
    }

    public List<JSONObject> getInvoiceDetailList() {
        return invoiceDetailList;
    }

    public void setInvoiceDetailList(List<JSONObject> invoiceDetailList) {
        this.invoiceDetailList = invoiceDetailList;
    }

    public List<JSONObject> getReceiveDetailList() {
        return receiveDetailList;
    }

    public void setReceiveDetailList(List<JSONObject> receiveDetailList) {
        this.receiveDetailList = receiveDetailList;
    }

    public List<JSONObject> getSettleList() {
        return settleList;
    }

    public void setSettleList(List<JSONObject> settleList) {
        this.settleList = settleList;
    }

    public List<JSONObject> getContractList() {
        return contractList;
    }

    public void setContractList(List<JSONObject> contractList) {
        this.contractList = contractList;
    }

    public List<Integer> getProjectStatusList() {
        return projectStatusList;
    }

    public void setProjectStatusList(List<Integer> projectStatusList) {
        this.projectStatusList = projectStatusList;
    }
}
